#
# spec file for package bottom
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bottom
Version:        0.9.6~0
Release:        2.2
Summary:        Yet another graphical process/system monitor
License:        Apache-2.0 AND MIT
Group:          System/Monitoring
URL:            https://github.com/ClementTsang/bottom
Source:         %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description
A cross-platform graphical process/system monitor with a
customizable interface and a multitude of features.

%prep
%autosetup -p 1 -a 1
install -D -m 0644 %{SOURCE2} .cargo/config

%build
cargo build --release --locked %{?_smp_mflags}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%doc sample_configs/*
%{_bindir}/btm

%changelog
* Tue Aug 29 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correct license to MIT and Apache-2.0
* Sun Aug 27 2023 opensuse-packages@jlk.one
- Update to version 0.9.6~0:
  * uptick: 0.9.6 (#1288)
  * deps: bump dependencies as of 2023-08-26 (#1287)
  * deps: pin serde to 1.0.188 (#1286)
  * docs: update changelog dates
  * ci: pin musl to 1.71.0 for now when building releases (#1282)
  * other: appease clippy after Rust 1.72.0 (#1281)
  * uptick: 0.9.5 (#1280)
  * deps: bump windows to 0.51.1 (#1279)
  * deps: bump dependencies as of 2023-08-18 (#1277)
  * deps: pin serde to <=1.0.171 (#1278)
  * deps: pin sysinfo to 0.29.8 (#1273)
  * deps: bump deps as of 2023-08-08 (#1272)
* Sun Aug 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.6:
  * #1286: Pin serde to 1.0.188 to help with potential cargo install
    issues. Note this version should be fine and not pull in binaries.
* Sun Aug 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.5:
  * #1278: Pin serde to 1.0.171.
* Sun Aug  6 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.9.4:
  Bug Fixes:
  * #1230: Fix core dump if the terminal is closed while bottom is
    open.
  * #1264: Fix ARC usage showing max system memory instead of max
    ARC size.
  Features:
  * #1248: Add I/O counters from ZFS for Linux and FreeBSD.
  Changes:
  * #1236: Hide the battery tab selector if there is only one
    battery detected.
  * #1251: Make the charge meter take the entire width of the
    battery widget.
* Mon Jun 26 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.3:
  * #1216: Fix arguments not being sorted alphabetically.
  * #1219: Fix overflow/underflow in graph timespan zoom.
  * #1221: Support human times for rate.
  * #1206: Add .rpm package generation.
  * #1220: Update documentation for features supporting human times.
* Mon Jun 12 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.2:
  Bug Fixes:
  * #1186: Fix for temperature sensor data gathering on Linux immediately halting if any method failed.
  * #1191: Fix ntfs3 mounts not being counted as a physical drive type.
  * #1195: Fix battery health being incorrectly reported on M1 macOS.
  * #1188: Don't fail fast with temperature sensor name generation on Linux.
  Features:
  * #1172: Support human times for time_delta and default_time_value.
  * #1187: Use better names for duplicate temp sensors on Linux.
  * #1188: Also check /sys/devices/platform/coretemp.* for temp sensors on Linux.
  Other:
  * #1199: bottom should build on aarch64-linux-android with features disabled.
* Sun May 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * #1148: Fix Gruvbox colour string being invalid when cache usage
    is enabled.
* Thu May 11 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Add memory build constraint
* Wed May 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  Bug Fixes:
  * #1021: Fix selected text background colour being wrong if only
    the foreground colour was set.
  * #1037: Fix is_list_ignored accepting all results if set to false
  * #1064: Disk name/mount filter now doesn't always show all
    entries if one filter wasn't set.
  * #1064: macOS disk I/O is potentially working now.
  * #597: Resolve RUSTSEC-2021-0119 by removing heim.
  Features:
  * #1016: Add support for displaying process usernames on Windows
  * #1022: Support three-character hex colour strings for styling.
  * #1024: Support FreeBSD temperature sensors based on hw.temperature.
  * #1063: Add buffer and cache memory tracking.
  * #1106: Add current battery charging state.
  * #1115: Add customizable process columns to config file.
  * #801: Add optional process time column and querying.
  Changes:
  * #1025: Officially support M1 macOS.
  * #1035: Migrate away from heim for CPU information.
  * #1036: Migrate away from heim for memory information; bottom
    will now try to use MemAvailable on Linux to determine used memory.
  * #1041: Migrate away from heim for network information.
  * #1064: Migrate away from heim for storage information.
  * #812: Fully remove heim from bottom.
  * #1075: Update how drives are named in Windows.
  * #1106: Rename battery consumption field to rate.
  Other:
  * #1008: Fix clap 3 deprecation warnings.
  * #1044: Re-enable ZFS feature.
  * #1100: Speed up first draw and first data collection.
  * #1107: Update to clap v4.
  * #1111: Update to regex 1.8.0, supporting more escapable characters
    and named captures.
* Mon Jan 23 2023 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.8.0:
  * Bug Fixes
    + Update help menu for disk and temperature widgets with
    sorting support.
    + Fix time graph labels not being styled.
  * Features
    + Split usage into both usage percentage and usage value.
  * Changes
    + Hide battery duration section if the value is unknown. Also
    update shortened text.
    + Automatically hide the battery widget if no batteries are
    found but --battery is enabled.
* Fri Jan  6 2023 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.7.1:
  * Bug Fixes
    + Fixes invalid sorting order for disk usage percentage
    + Partially fix battery text getting cut off in small windows
    + Fix CPU widget's 'all' label being missing on small sizes
* Sun Jan  1 2023 Jan-Luca Kiok <me@jlk.one>
- Add build dependency to zstd compression tool
* Sun Jan  1 2023 Jan-Luca Kiok <me@jlk.one>
- Apply current rust service template
- Change source compress algorithm
- Use cargo test for check stage
- Update to version 0.7.0:
  * Bug Fixes
    + Fix building in Rust beta 1.61 due to `as_ref()` calls
    causing type inference issues.
    + Fix clicking on empty space in tables selecting the very last
    entry of a list in some cases.
    + Fix panic if battery feature was disabled during compilation.
    + Fix bottom keeping devices awake in certain scenarios
    + Use alternative method of getting parent PID in some cases on
    macOS devices to avoid needing root access.
    + Fix possible gaps with widget layout spacing.
    + Fix search scrolling with wider Unicode characters.
  * Changes
    + Add some colour to `-h`/`--help` as part of updating to clap
    3.0.
    + Add ARM musl binary build tasks.
    + Add more human friendly temperature sensor names for Linux
    + Add macOS M1, FreeBSD 12, and FreeBSD 13 binary build tasks.
    + Improve CPU usage by optimizing draw logic of charts and
    tables.
  * Features
    + Add support for NVIDIA GPU temperature sensors
    + Add a check for whether bottom is being run in a terminal.
    + Add FreeBSD support
    + Add half page scrolling with `ctrl-u` and `ctrl-d`
    + Add ZFS ARC support
    + Add GPU memory support for NVIDIA GPUs
    + Update sysinfo to support M1 macOS temperature sensors.
    + Add CLI options for GPU memory
    + Add page up/page down support for the help screen
    + Make temperature widget sortable.
    + Make disk widget sortable.
    + Add pasting to the search bar.
    + Add custom retention periods for data.
    + Add non-normalized CPU usage to processes
    + Add an option to expand the default widget on startup
  * Other
    + Fix dead links in docs
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Mar 18 2022 Jan-Luca Kiok <me@jlk.one>
- Package version appropriate deps
* Fri Mar 18 2022 Jan-Luca Kiok <me@jlk.one>
- Update to 0.6.8:
  * Add PgUp/PgDown keybind support to scroll up and down a page in
    a table
  * Fix bug where the program would stall in an infinite loop if
    the width of the terminal was too small
  * Fix a bug where the number of CPUs is never refreshed
  * Update sysinfo
- Strip binary
- Require cargo version 1.58 at least for binary stripping on cargo
  build
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.6:
  * Address RUSTSEC-2020-0071
  * Fixes process_command breaking process widget sorting
  * Fix process CPU calculation if /proc/stat CPU line has less values than expected
  * Remove duplicate guest time in process CPU calculation
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.4
  * Small update to fix a bug and being slightly clearer on the
    network legend unit.
- Update to version 0.6.3
  * Small release with some bug fixes and a change in how we
    calculate Linux memory usage.
- Update to version 0.6.2
  Features
  * Add F9 key as an alternative process kill key.
  Bug Fixes
  * Fixes two bugs causing the battery widget colours and mouse
    events to be broken.
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.1
  * Fine-grained kill signals - bottom defaulted to kill -15, but
    now, on Unix-based systems, you can directly choose which kill
    signal you want.
  * You can disable this feature if you want with the
  - -disable_advanced_kill flag or config option, which will
    instead revert to the older style with just two options.
  * Scroll position indicator using --show_table_scroll_position.
  * Added Nord colour schemes. This can be enabled either in the
    config file or command line with color=nord or color=nord-light.
  * Add Ctrl-w and Ctrl-h shortcuts in search in order to delete a
    word or a character respectively.
  * Added mouse support for sorting process columns:
  * Added users as a column in the process widget.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.7
  * Fixes incorrect colours being used the CPU widget in basic
    mode.
  * Fixes hide_table_gap not working in the battery widget.
  * Fixes the sorting arrow disappearing in proc widget under
    some cases.
  * Fixes basic mode failing to report CPUs if there are less than
    4 entries to report.
- Update to version 0.5.6
  * Fixed temperature sensors not working at all on non-Linux
    platforms.
- Update to version 0.5.5
  * Fixed CPU graph colours not matching the legend in the "all"
    state.
- Update to version 0.5.4
  Changes
  * Removed the --debug option for now.
  Bug Fixes
  * Fixes a performance regression causing high memory and CPU
    usage over time.
  * Fixes process states not showing.
* Sat Nov 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.3
  * Fixes custom battery colour levels being inverted.
- Update to version 0.5.2
  * Fixes hide_avg_cpu being inverted in config files.
- Update to version 0.5.1
  * Patch for some bugs that were spotted in the 0.5.0 release.
- Update to version 0.5.0
  Features
  * Adaptive network graphs: the network widget's y-axis will now
    adjust based on your current usage.
  * Mouse support for tables and moving to widgets.
  * The ability to hide specific temperature and disk entries
    via config.
  * Added a tree mode, you can access this with the t key.
  * A simple indicator for when data updating is frozen.
  * Built-in colour themes.
  Changes
  * Updated help descriptions, added auto-complete generation.
  * Changed how we do battery theming. We now only set high,
    medium, and low colours and we deal with the ratios.
  Bug Fixes
  * Fixes a bug where you could move down in the process widget
    even if the process widget search was closed.
  * Add labels to Linux temperature values.
  * Implements sorting by count. It previously did absolutely
    nothing.
  * Fix being able to cause an index out-of-bounds by resizing to
    a smaller terminal just after the program got the terminal
    size, but right before the terminal started drawing.
  * Fixed not clearing screen before drawing, which caused issues
    for some environments.
  * Fix highlighted entries being stuck in another colour when the
    widget is not selected.
  * Expanding a widget no longer overrides the widget/dialog title
    colour.
  * Fixed process names occasionally showing up as truncated, due
    to only using /proc//stat as our data source.
  * Fixed missing thread termination steps as well as improper
    polling causing blocking in input thread.
  * Fixed the CPU basic widget showing incorrect data due to an
    incorrect offset when displaying the data.
  * Fixed an incorrect offset affecting the CPU colour when
    scrolling.
  * Fixed spacing problems in basic CPU mode.
  * Fixed an incorrect offset affecting the graph CPU colour
    mismatching the legend.
  * Removes an accidental extra comma in one of the headers in the
    disk widget.
  * Removes the automatically generated CPU colours method.
* Sun Aug 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.7
  * Just a single bug fix, where searching by command name was
    broken.
- Update to version 0.4.6
  * Minor update, with some bug fixes, changes, and new features.
    Most of the work done was refactoring and updating old, weird
    code.
  Features
  * Allow using P to toggle between the processes' base name and
    the processes' full name
  * Added sorting capabilities for any column. Using s will open
    up a menu allowing you to select which column you want to sort
    by.
  * Added I to invert the current process sort.
  * Added the ability to toggle between mem%% and actual memory
    values by using %% in the process widget:
  * Support searching processes by state (i.e. state=sleeping).
  * Added WASD as an alternative method to moving between widgets.
  * Made e also escape expanded widgets (so e expands, then
    pressing e again will shrink the widget, like if you had pressed
    ESC).
  Changes
  * Dropped MSRV (for now), mainly supporting stable and newer
    versions of Rust.
  Bug fixes
  * Fixed bug in basic mode where the battery widget was placed
    incorrectly.
  * Fixed a bug caused by hitting Enter when a process kill fails,
    breaking future process kills.
  * Fix bug caused by incorrectly reading the /proc/{pid}/stats file.
- Update to version 0.4.5
  * Minor update to match needing to update on crates.io.  No changes.
* Mon Jul  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.4
  Features
  * Added process states to the processes widget.
  Bug Fixes
  * Fixed a bug where bottom would incorrectly read the wrong
    values to calculate the read/write columns for processes
    in Linux.
  * Fixed a bug where OR operations in the process query wouldn't
    properly for some cases.
  * Improved process query overall
  Changes
  * Showing average CPU is now on by default. Disable it via flag.
  * Removed CPU filtering. I didn't like it and had planned on
    rolling out this change with an alternative, more usable CPU
    widget system. Note, if you liked it, let me know, it's easy
    to add back in as an option but for now, I ripped it out since
    it was causing more headaches.
  * show_disabled_data flag and option are also removed as they
    are now irrelevant.
  * Made the CPU entry you're scrolling over highlight even when
    you're not on the widget.
* Fri May 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.3
  * Minor update to update a dependency to avoid an overflow.
* Tue May 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.2
  Changes
  * Automatically hide time axis labels if the widget gets too
    small.
  * Automatically hide table gap if the widget gets too small.
  Bugs
  * The <Space> character can be used as an "AND" again (properly)
    in queries. For example:
  * Fixed an issue where if the drive I/O label didn't match any
    disk, the entire disk widget would display no results.
  * Display SWAP and MEM legends even if the total amount is 0 to
    avoid a weird blank spot in the legend.
* Sat May  9 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.4.1
